@@ -9,7 +9,7 @@ use Child::Link::Parent;
 
 use Exporter 'import';
 
-our $VERSION = "0.008";
+our $VERSION = "0.011";
 our @PROCS;
 our @EXPORT_OK = qw/child/;
 
@@ -23,6 +23,13 @@ sub child(&;@) {
 
 sub all_procs { @PROCS }
 
+sub _clean_proc {
+    my $class = shift;
+    my ($proc) = @_;
+    return unless $proc;
+    @PROCS = grep { $proc != $_ } @PROCS;
+}
+
 sub all_proc_pids {
     my $class = shift;
     map { $_->pid } $class->all_procs;
@@ -68,7 +75,13 @@ sub start {
     @PROCS = ();
     my $parent = $self->parent_class->new( $ppid, @data );
     my $code = $self->code;
-    $code->( $parent );
+
+    # Ensure the child code can't die and jump out of our control.
+    eval { $code->( $parent ); 1; } || do {
+        # Simulate die without dying.
+        print STDERR $@;
+        exit 255;
+    };
     exit;
 }
 
@@ -91,6 +104,9 @@ Child is an Object Oriented interface to fork. It provides a clean way to start
 a child process, and manage it afterwords. It provides methods for running,
 waiting, killing, checking, and even communicating with a child process.
 
+B<NOTE>: kill() is unpredictable on windows, strawberry perl sends the kill
+signal to the parent as well as the child.
+
 =head1 SYNOPSIS
 
 =head2 BASIC
@@ -102,10 +118,10 @@ waiting, killing, checking, and even communicating with a child process.
         ....
         # exit() is called for you at the end.
     });
-    my $proc = $child->start
+    my $proc = $child->start;
 
     # Kill the child if it is not done
-    $proc->complete || $proc->kill(9);
+    $proc->is_complete || $proc->kill(9);
 
     $proc->wait; #blocking
 
@@ -228,7 +244,7 @@ The proc object that is returned by $child->start()
 
 =item L<Child::Link::Parent>
 
-The parent object that is provided as the argumunt to the function used to
+The parent object that is provided as the argument to the function used to
 define the child.
 
 =item L<Child::Link::IPC>
@@ -250,7 +266,7 @@ Together the tools that make up the Fennec framework provide a potent testing
 environment.
 
 The tools provided by Fennec are also useful on their own. Sometimes a tool
-created for Fennec is useful outside the greator framework. Such tools are
+created for Fennec is useful outside the greater framework. Such tools are
 turned into their own projects. This is one such project.
 
 =over 2
